- text
The text to show in the message.
- refresh
The text to show in a link that allows the user to refresh the page.
Use refresh = "" if you don't want to show a refresh link.
- width
The width of the message box. Must be either an integer, or the string
"full" to make the message take up the entire page width.
- top
The distance from the message to the top of the page. Must be either
an integer, or the string "center" to make the box vertically centered.
- size
The font size of the text. (integer).
- background
The background colour of the message box.
- colour
The colour of the text of the message box.
- overlayColour
The colour of the overlay to draw on the page behind the message box.
An overlay is used to "grey out" the application and draw attention to the message. Use
overlayOpacity = 0 to disable the overlay.
- overlayOpacity
The opacity of the overlay, from 0 (fully transparent/not visible) to 1
(fully opaque). Use overlayOpacity = 0 to disable the overlay.
- refreshColour
The colour of the refresh text link
- css
Any additional CSS rules to apply to the message box. For example,
css = "padding: 0 !important; border: 3px solid red;" will remove padding and add a border.
Note that you may need to use the !important rule to override default styles.